.. EGADS documentation master file, created by
   sphinx-quickstart on Tue May 24 15:43:01 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to EGADS's documentation!
=================================

.. toctree::
   :maxdepth: 3

   intro
   install
   tutorial
   alg_development
   egadsapi
